##

.onLoad <- function(libname, pkgname)
{
##  library.dynam("SV", pkgname, libname)
}
